@@ -1299,13 +1299,8 @@ void CanvasNode::paint(QPainter* p,
     p->drawRect(QRect(origRect.x(), origRect.y(), origRect.width()-1,
                       origRect.height()-1));
 
-#if QT_VERSION >= 0x040600
     if (option->levelOfDetailFromTransform(p->transform()) < .5)
         return;
-#else
-    if (option->levelOfDetail < .5)
-        return;
-#endif
 
     d.setRect(r);
     d.drawField(p, 0, this);
@@ -1369,13 +1364,8 @@ void CanvasEdgeLabel::paint(QPainter* p,
                             const QStyleOptionGraphicsItem* option, QWidget*)
 {
     // draw nothing in PanningView
-#if QT_VERSION >= 0x040600
     if (option->levelOfDetailFromTransform(p->transform()) < .5)
         return;
-#else
-    if (option->levelOfDetail < .5)
-        return;
-#endif
 
     QRect r = rect().toRect();
 
@@ -1464,11 +1454,7 @@ void CanvasEdge::paint(QPainter* p,
     p->setRenderHint(QPainter::Antialiasing);
 
     qreal levelOfDetail;
-#if QT_VERSION >= 0x040600
     levelOfDetail = option->levelOfDetailFromTransform(p->transform());
-#else
-    levelOfDetail = option->levelOfDetail;
-#endif
 
     QPen mypen = pen();
     mypen.setWidthF(1.0/levelOfDetail * _thickness);
@@ -1533,11 +1519,7 @@ void CanvasFrame::paint(QPainter* p,
                         const QStyleOptionGraphicsItem* option, QWidget*)
 {
     qreal levelOfDetail;
-#if QT_VERSION >= 0x040600
     levelOfDetail = option->levelOfDetailFromTransform(p->transform());
-#else
-    levelOfDetail = option->levelOfDetail;
-#endif
     if (levelOfDetail < .5) {
         QRadialGradient g(rect().center(), rect().width()/3);
         g.setColorAt(0.0, Qt::gray);
